@@ -4,18 +4,20 @@
 #include <QString>
 #include <QProgressDialog>
 
+/** Simple wrapper for QProgressDialog. */
 class ProgressDialog: public QProgressDialog
 {
     Q_OBJECT
 
 public:
     explicit ProgressDialog(const QString &label, QWidget *parent = 0);
-    void showWait();
-
-signals:
 
 public slots:
+    /** Show wait animation instead of progress bar. */
+    void showWait();
 
+    /** Show dialog, adjust position if needed. */
+    void show();
 };
 
 #endif // PROGRESSDIALOG_H
